==> jc-1.4.0.tar.gz: polyglot/visit/DataFlow__24FlowGraphSource.h <==
// public class polyglot.visit.DataFlow$FlowGraphSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 740f68f94c9e9854 polyglot_visit_DataFlow__24FlowGraphSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_
#define _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_visit_FlowGraph$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$refs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$refs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object	_jc_polyglot_visit_DataFlow__24FlowGraphSource$object;

typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24FlowGraphSource$method$_init$23bd816ca9e762d2(_jc_env *, struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods {
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods	polyglot_visit_DataFlow__24FlowGraphSource;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs {
	struct _jc_polyglot_visit_FlowGraph$object	*flowgraph;
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$refs {
    _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs	polyglot_visit_DataFlow__24FlowGraphSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs	polyglot_visit_DataFlow__24FlowGraphSource;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object {
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype _jc_polyglot_visit_DataFlow__24FlowGraphSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24FlowGraphSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24FlowGraphSource$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/DataFlow__24FlowGraphSource.h <==
// public class polyglot.visit.DataFlow$FlowGraphSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 740f68f94c9e9854 polyglot_visit_DataFlow__24FlowGraphSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_
#define _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_visit_FlowGraph$object;

// Typedefs
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$refs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$refs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs	_jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs;
typedef struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object	_jc_polyglot_visit_DataFlow__24FlowGraphSource$object;

typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods;
typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable;
typedef const struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype;

// Constructors
extern void _jc_polyglot_visit_DataFlow__24FlowGraphSource$method$_init$23bd816ca9e762d2(_jc_env *, struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods {
};

// Vtable
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vmethods	polyglot_visit_DataFlow__24FlowGraphSource;
};

// Vtype
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype {
	_jc_type			type;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs {
	struct _jc_polyglot_visit_FlowGraph$object	*flowgraph;
	struct _jc_object	*source;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$refs {
    _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_refs	polyglot_visit_DataFlow__24FlowGraphSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24FlowGraphSource$sub_nonrefs	polyglot_visit_DataFlow__24FlowGraphSource;
};

// Object instance structure
struct _jc_polyglot_visit_DataFlow__24FlowGraphSource$object {
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype	*vtype;
	_jc_polyglot_visit_DataFlow__24FlowGraphSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_DataFlow__24FlowGraphSource$vtype _jc_polyglot_visit_DataFlow__24FlowGraphSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_DataFlow__24FlowGraphSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_DataFlow__24FlowGraphSource$class_object;

#endif	/* _JC_polyglot_visit_DataFlow__24FlowGraphSource_H_ */
